#!/bin/sh
#   Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh

serve_file() {
    echo "Content-Type: application/octet-stream; charset=binary"
    echo "Content-Disposition: attachment; filename=\"$1\""
    echo ""
    cat "/tmp/$1"
}

serve_error() {
    echo "Content-Type: text/html; charset=utf-8;"
    echo "Content-Disposition: attachment; filename=\"error.html\""
    echo ""
    echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">"
    echo "<html xmlns=\"http://www.w3.org/1999/xhtml\">"
    echo "<head>"
    echo "<title>Error</title>"
    echo "</head>"
    echo "<body>"
    echo "<h1>Error</h1>"
    echo "$1"
    echo "</body>"
    echo "</html>"
}

if [[ -z "$1" ]]; then
    serve_error "Missing backup id parameter"
    exit 1
fi

echo "$1" | egrep '^[a-zA-Z0-9_\-]+$' > /dev/null 2>&1
if [[ $? -ne 0 ]]; then
    serve_error "Invalid backup id parameter"
    exit 1
fi

FILENAME="$1.dss"

if [[ ! -f "/tmp/$FILENAME" ]]; then
    serve_error "Requested backup file not found"
    exit 1
fi

serve_file $FILENAME

rm -f "/tmp/$1.dss" > /dev/null 2>&1

