Ext.namespace('dSS11', 'dSS11.sys');

dSS11.sys.TimeForm = Ext.extend(Ext.form.FormPanel,
{
    initComponent: function()
    {
        this.zoneStore = new Ext.data.JsonStore({
            url: '/cgi-bin/zonelist.sh',
            root: 'data.zonelist',
            fields: [ 'zone' ]
        });

        this.ntpPanel = new Ext.Panel(
                       {
                            xtype: 'panel',
                            layout: 'hbox',
                            scope: this,
                            bodyBorder: false,
                            height: 25,
                            ref: 'ntpPanel',
                            items: [
                                {
                                    xtype: 'label',
                                    text: _("NTP server"),
                                    flex: 1
                                },
                                {
                                    xtype: 'textfield',
                                    allowBlank: false,
                                    name: 'ntpserver',
                                    width: 220
                                }
                            ]
                        }); // ntp panel

        this.timeField = new Ext.form.TimeField({
            xtype: 'timefield',
            ref: 'time',
            format: 'H:i:s',
            name: 'settime',
            width: 220
        });

        this.dateField = new Ext.form.DateField({
            xtype: 'datefield',
            anchor: '100%',
            ref: 'date',
            name: 'setdate',
            format: 'd-m-Y',
            width: 220
        });

        this.datePanel = new Ext.Panel(
                        {
                            xtype: 'panel',
                            ref: 'datePanel',
                            scope: this,
                            layout: 'form',
                            bodyBorder: false,
                            hidden: true,
                            items: [
                                {
                                    xtype: 'panel',
                                    border: false,
                                    layout: 'hbox',
                                    items:
                                    [
                                        {
                                            xtype: 'label',
                                            text: _("Date"),
                                            flex: 1
                                        },
                                        this.dateField
                                    ]
                                },
                                {
                                    xtype: 'box',
                                    height: 10
                                },
                                {
                                    xtype: 'panel',
                                    border: false,
                                    layout: 'hbox',
                                    items:
                                    [
                                        {
                                            xtype: 'label',
                                            text: _("Time"),
                                            flex: 1
                                        },
                                        this.timeField
                                    ]
                                }
                            ]
                        }); // date panel

        var timePanel =
        {
            xtype: 'panel',
            bodyBorder: false,
            items: [
                {
                    xtype: 'checkbox',
                    name: 'ntp',
                    ctCls: 'x-black-text',
                    hideBorders: true,
                    boxLabel: _("Synchronize date and time over the network"),
                    checked: true,
                    listeners: {
                        check: this.NTPChecked.createDelegate(this)
                    }
                },
                {
                    xtype: 'panel',
                    bodyBorder: false,
                    layout: 'fit',
                    ref: 'ntpPanelSwitch',
                    items: [
                        this.ntpPanel,
                        this.datePanel
                    ]
                } // panel with all ntp and date/time settings
            ] // fieldset items
        };

        var timeSet =
            {
                xtype: 'fieldset',
                title: _("Date and time settings"),
                layout: 'form',
                items: [
                    {
                        xtype: 'panel',
                        ref: 'current',
                        id: 'currentTime',
                        cls: 'x-green-text',
                        autoEl: 'span',
                        height: 20,
                        bodyBorder: false
                    },
                    {
                        xtype: 'box',
                        height: 10
                    },
                    {
                        xtype: 'panel',
                        scope: this,
                        height: 25,
                        layout: 'absolute',
                        bodyBorder: false,
                        items: [
                            {
                                xtype: 'label',
                                text: _("Time zone") + ': ',
                                x: 0,
                                y: 3
                            },
                            {
                                xtype: 'combo',
                                lazyInit: false,
                                mode: 'local',
                                name: 'timezone',
                                forceSelection: true,
                                store: this.zoneStore,
                                emptyText: _("Select a time zone") + "...",
                                triggerAction: 'all',
                                typeAhead: true,
                                displayField: 'zone',
                                valueField: 'zone',
                                width: 220,
                                x: 146,
                                y: 0
                            }

                        ]
                    }, // time zone panel
                    {
                        xtype: 'box',
                        height: 10
                    },
                    timePanel,
                    {
                        xtype: 'box',
                        height: 10
                    },
                    {
                        bodyBorder: false,
                        xtype: 'panel',
                        layout: 'absolute',
                        height: 25,
                        items: [
                            {
                                xtype: 'button',
                                text: _("Apply"),
                                minWidth: 90,
                                x: 275,
                                y: 0,
                                handler: this.applyTimeSettings.createDelegate(this)
                            }
                        ]
                    }
                ] // timeset items
            };

        Ext.apply(this, {
            padding: 6,
            width: 400,
            items: [ timeSet ]
        });

        dSS11.sys.TimeForm.superclass.initComponent.apply(this, arguments);

        this.zoneStore.load();

        dSS11.MessageBus.on('refreshdatetime',
                            this.reloadTimeSettings.createDelegate(this),
                            this);
    },
    reloadTimeSettings: function() {
        this.el.mask(_("Loading date and time settings") + "...",
                  'x-mask-loading');

        this.load({
            url: '/cgi-bin/dateinfo.sh',
            method: 'GET',
            scope: this,
            disableCaching: true,
            success: function(form, action) {
                try {
                    var jsonData = Ext.util.JSON.decode(
                                            action.response.responseText);

                    if (jsonData.success !== true) {
                        Ext.Msg.alert(_("Error"), _(jsonData.message));
                        this.el.unmask();
                        return;
                    }

                    dSS11.config.dSS11TimeDiff = dSS11.config.dSS11TimeDiff = ((new Date().getTime()) - (jsonData.data.utcsecs * 1000));
                    if (dSS11.config.timeUpdateTimeout !== 0) {
                        clearTimeout(dSS11.config.timeUpdateTimeout);
                    }
                    dSS11.config.timeZoneShort = jsonData.data.zoneshort;
                    dSS11.time.update();
                } catch (error) {
                    Ext.Msg.alert(_("Error"),
                        _("Could not load date and time settings") +
                            ": "  + error.message);
                }

                this.el.unmask();
            },
            failure: function(form, action) {
                switch (action.failureType) {
                    case Ext.form.Action.CONNECT_FAILURE:
                        Ext.Msg.alert(_("Error"),
                            _("Ajax communication failed"));
                    break;
                    default:
                        Ext.Msg.alert(_("Error"),
                                _("Could not load date and time settings"));
                    break;
                }
                this.el.unmask();
            }
        });
    },
    applyTimeSettings:  function() {
        if (!this.getForm().isValid()) {
            Ext.Msg.alert(_("Error"), _("The data you entered is invalid!"));
            return;
        }

        this.el.mask(_("Applying changes") + '...', 'x-mask-loading');

        this.getForm().submit({
            url: '/cgi-bin/setdatewrapper.sh',
            method: 'GET',
            scope: this,
            success: function(form, action) {
                this.el.unmask();
                this.dateField.setValue("");
                this.timeField.clearValue();
                this.reloadTimeSettings();
                dSS11.StatusBar.setMessage(_("Date and time settings applied " +
                                           "successfully"));
            },
            failure: function(form, action) {
                this.el.unmask();
                switch (action.failureType) {
                    case Ext.form.Action.CONNECT_FAILURE:
                        Ext.Msg.alert(_("Error"),
                            _("Ajax communication failed"));
                    break;
                    default:
                        Ext.Msg.alert(_("Error"),
                                _("Could not set date and time") +
                                ": " + _(action.result.message));
                    break;
                }
            }
        });
    },
    NTPChecked: function(box, checked) {

        if (checked === true) {
            this.datePanel.setVisible(false);
            this.ntpPanel.setVisible(true);
        } else {
            this.ntpPanel.setVisible(false);
            this.datePanel.setVisible(true);
        }
    }

});

Ext.reg('dss11systimeform', dSS11.sys.TimeForm);
